@@ -101,6 +101,8 @@ sub find_text_nodes {
     $runs->foreach(sub {
         my $run = shift;
 
+        my $run_was_split = 0;
+
         my $text_nodes = $self->xpc->findnodes('./w:t', $run);
         $text_nodes->foreach(sub {
             my $t = shift;
@@ -111,6 +113,8 @@ sub find_text_nodes {
             # No match, no need to do all the DOM processing below
             return if @parts == 1;
 
+            $run_was_split = 1;
+
             for (my $i = $#parts; $i >= 0; $i--) {
                 my $part = $parts[$i];
                 next if $part eq '';
@@ -133,7 +137,7 @@ sub find_text_nodes {
             }
         });
 
-        $run->parentNode->removeChild($run);
+        $run->parentNode->removeChild($run) if $run_was_split;
     });
 
     for my $part ($self->referenced_parts) {
@@ -149,6 +153,66 @@ sub find_text_nodes {
 }
 
 
+sub style_text {
+    my $self = shift;
+    my $regex = shift;
+    my %options = @_;
+
+    my $text_nodes = $self->find_text_nodes($regex, delete $options{exclude_tables});
+
+    for my $text_node (@$text_nodes) {
+        my ($run_props) = $self->xpc->findnodes('../../w:rPr', $text_node);
+        if (!$run_props) {
+            my ($run) = $self->xpc->findnodes('../w:r', $text_node);
+            $run_props = $run->addNewChild($run->namespaceURI => 'rPr');
+        }
+
+        if (exists $options{bold}) {
+            my ($bold) = $self->xpc->findnodes('./w:b', $run_props);
+
+            if (!$bold && $options{bold}) {
+                $run_props->addNewChild($run_props->namespaceURI => 'b');
+            }
+            if ($bold && !$options{bold}) {
+                $run_props->removeChild($bold);
+            }
+        }
+
+       if (exists $options{italic}) {
+            my ($italic) = $self->xpc->findnodes('./w:i', $run_props);
+
+            if (!$italic && $options{italic}) {
+                $run_props->addNewChild($run_props->namespaceURI => 'i');
+            }
+            if ($italic && !$options{italic}) {
+                $run_props->removeChild($italic);
+            }
+        }
+
+        if (exists $options{color}) {
+            my ($color) = $self->xpc->findnodes('./w:color', $run_props);
+
+            if (!$color && $options{color}) {
+                $color = $run_props->addNewChild($run_props->namespaceURI => 'color');
+            } 
+
+            if ($color && $options{color}) {
+                $color->setAttributeNS(
+                    $color->namespaceURI,
+                    'val' => $options{color}
+                );
+            }
+
+            if ($color && !$options{color}) {
+                $run_props->removeChild($color);
+            }
+        }
+    }
+
+    return;
+}
+
+
 sub remove_spellcheck_markers {
     my $self = shift;
 
@@ -374,7 +438,7 @@ Document::OOXML::Part::WordprocessingML - WordprocessingML document part handlin
 
 =head1 VERSION
 
-version 0.172650
+version 0.180740
 
 =head1 ATTRIBUTES
 
@@ -410,6 +474,49 @@ confuse the splitting code.
 If C<$exclude_tables> is true, the regular expression will not match
 text in tables. This option may change in the future.
 
+=head2 style_text($regex, %style)
+
+Sets the style options described by C<%style> to all text parts of the document
+that match regular expression C<$regex>.
+
+Internally, this method uses L</find_text_nodes> to do the heavy lifting of
+combining and splitting runs.
+
+The regular expression should not contain matching groups, as this will confuse
+the splitting code.
+
+The following style options are recognised (all are optional, but why would you
+call this method if you don't want to set/unset styling?):
+
+=over
+
+=item * bold
+
+Boolean value. If true, matching text will be made B<bold>. If specified and
+false, matching text will be un-bolded.
+
+=item * italic
+
+Boolean value. If true, matching text will be made I<italic>. If specified and
+false, matching text will be un-italiced.
+
+=item * color
+
+Color value, matching text will be given this color.
+
+Colors should be in the format: C<RRGGBB> (red, green, blue components in
+hexadecimal, like used in HTML). The special value C<auto> can be used to
+let the word processor decide the color.
+
+Note: unlike HTML, the color value should NOT be prefixed with "#". It
+should just be the six hexadecimal digits.
+
+=item * exclude_tables
+
+Boolean value. If true, text in tables will not be touched.
+
+=back
+
 =head2 remove_spellcheck_markers
 
 Remove all C<< <w:proofErr> >> elements from the document. This removes
